starcluster.threadpool

Package starcluster :: Module threadpool |
[hide private]
[frames] | no frames]

# Module threadpool

source code

ThreadPool module for StarCluster based on WorkerPool

Classes | [hide private]
| DaemonWorker Improved Worker that sets daemon = True by default and also handles communicating exceptions to the parent pool object by adding them to the parent pool's exception queue
| SimpleJob
| ThreadPool

Functions | [hide private]
_worker_factory(parent) | source code
get_thread_pool(size=10, worker_factory=<function _worker_factory at 0x1829668>, disable_threads=False) | source code

Variables | [hide private]
| __package__ = ``'``starcluster``'``